"use client";

import { cn } from "@/lib/utils";
import { useNotifications } from "@/servers/data/use-notification";
import { Bell, ChevronLeft, ChevronRight } from "lucide-react";
import moment from "moment";
import "moment/locale/ar";
import { useLocale, useTranslations } from "next-intl";
import { useState } from "react";

const ITEMS_PER_PAGE = 10;

export default function NotificationsList() {
	const [page, setPage] = useState(1);
	const {
		notifications,
		isLoading,
		totalPages
	} = useNotifications(page, ITEMS_PER_PAGE);

	// Sort notifications by newest first
	const sortedNotifications = [...notifications].sort((a, b) =>
		new Date(b.created_at).getTime() - new Date(a.created_at).getTime()
	);

	const t = useTranslations();
	const locale = useLocale();

	const handlePrevPage = () => {
		if (page > 1) {
			setPage(page - 1);
		}
	};

	const handleNextPage = () => {
		if (page < totalPages) {
			setPage(page + 1);
		}
	};

	return (
		<div className="bg-white rounded-lg shadow-md p-6">
			{isLoading ? (
				<div className="flex justify-center py-12">
					<div className="animate-spin rounded-full h-10 w-10 border-b-2 border-blue-600"></div>
				</div>
			) : notifications.length > 0 ? (
				<>
					<div className="space-y-4 max-h-[70vh] overflow-y-auto scrollbar-thin scrollbar-thumb-gray-300 scrollbar-track-transparent">
						{sortedNotifications?.map((notification: any) => (
							<div
								key={notification.id}
								className={cn(
									"p-4 rounded-lg border transition-colors",
								)}
							>
								<div className="flex items-start gap-4">
									<div className="flex-grow text-right">
										<p className="text-gray-600">{locale === "ar" ? notification.description_ar : notification.description_en}</p>
									</div>
									<div className="flex-shrink-0">
										<span className="text-xs text-gray-500">
											{locale === "ar"
												? moment(notification.created_at).locale("ar").fromNow()
												: moment(notification.created_at).fromNow()}
										</span>
									</div>
								</div>
							</div>
						))}
					</div>
					{notifications.length > ITEMS_PER_PAGE && (
						<div className="flex items-center justify-between mt-4 pt-4 border-t">
							<button
								onClick={handlePrevPage}
								disabled={page === 1}
								className={cn(
									"flex items-center gap-2 px-4 py-2 text-sm rounded-md transition-colors",
									page === 1
										? "text-gray-400 cursor-not-allowed"
										: "text-gray-700 hover:bg-gray-100"
								)}
							>
								<ChevronRight className="h-4 w-4" />
								{t("Previous")}
							</button>
							<span className="text-sm text-gray-600">
								{t("Page")} {page} {t("of")} {totalPages}
							</span>
							<button
								onClick={handleNextPage}
								disabled={page >= totalPages}
								className={cn(
									"flex items-center gap-2 px-4 py-2 text-sm rounded-md transition-colors",
									page >= totalPages
										? "text-gray-400 cursor-not-allowed"
										: "text-gray-700 hover:bg-gray-100"
								)}
							>
								{t("Next")}
								<ChevronLeft className="h-4 w-4" />
							</button>
						</div>
					)}
				</>
			) : (
				<div className="text-center py-12">
					<Bell className="h-12 w-12 text-gray-300 mx-auto mb-4" />
					<h3 className="text-lg font-medium text-gray-900">{t("No notifications found")}</h3>
				</div>
			)}
		</div>
	);
} 